@@ -3,10 +3,11 @@ package org.gcube.applicationsupportlayer.social;
 import java.util.Date;
 import java.util.List;
 
-import org.gcube.portal.databook.shared.ApplicationProfile;
-import org.gcube.portal.databook.shared.RunningJob;
 import org.gcube.common.homelibrary.home.workspace.WorkspaceFolder;
 import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
+import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
+import org.gcube.portal.databook.shared.ApplicationProfile;
+import org.gcube.portal.databook.shared.RunningJob;
 /**
  * 
  * @author Massimiliano Assante, ISTI-CNR
@@ -17,10 +18,35 @@ public interface NotificationsManager {
 	 * use to notify a user he got a workspace folder shared
 	 *
 	 * @param userIdToNotify the user you want to notify
-	 * @param sharedFolder the shared {@link WorkspaceFolder}  
+	 * @param sharedFolder the shared {@link WorkspaceSharedFolder}  
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyFolderSharing(String userIdToNotify, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyFolderSharing(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception;
+	/**
+	 * use to notify a user he got a workspace folder shared
+	 *
+	 * @param userIdToNotify the user you want to notify
+	 * @param unsharedFolderId the unshared folder id
+	 * @param unsharedFolderName the unshared folder name
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyFolderUnsharing(String userIdToNotify, String unsharedFolderId, String unsharedFolderName) throws Exception;
+	/**
+	 * use to notify a user he got upgraded to Administrator of a folder shared
+	 *
+	 * @param userIdToNotify the user you want to notify
+	 * @param sharedFolder the shared {@link WorkspaceSharedFolder}  
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyAdministratorUpgrade(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception;
+	/**
+	 * use to notify a user he got downgraded from Administrator of a folder shared
+	 *
+	 * @param userIdToNotify the user you want to notify
+	 * @param sharedFolder the shared {@link WorkspaceSharedFolder}  
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyAdministratorDowngrade(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception;
 	/**
 	 * use to notify a user he got a workspace folder renamed
 	 *
@@ -35,52 +61,52 @@ public interface NotificationsManager {
 	 * use to notify a user that a new user was added in on of his workspace shared folder
 	 *
 	 * @param userIdToNotify the user you want to notify
-	 * @param sharedFolder the shared {@link WorkspaceFolder}  
+	 * @param sharedFolder the shared {@link WorkspaceSharedFolder}  
 	 * @param newAddedUserId the new user that was added
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String newAddedUserId) throws Exception;
+	boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceSharedFolder sharedFolder, String newAddedUserId) throws Exception;
 	/**
 	 * use to notify a user that a new user was added in on of his workspace shared folder
 	 *
 	 * @param userIdToNotify the user you want to notify
-	 * @param sharedFolder the shared {@link WorkspaceFolder}  
+	 * @param sharedFolder the shared {@link WorkspaceSharedFolder}  
 	 * @param newAddedUserIds List of new users that were added
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyFolderAddedUsers(String userIdToNotify, WorkspaceFolder sharedFolder, List<String> newAddedUserIds) throws Exception;
+	boolean notifyFolderAddedUsers(String userIdToNotify, WorkspaceSharedFolder sharedFolder, List<String> newAddedUserIds) throws Exception;
 	/**
 	 * use to notify a user that an existing user was removed from one of his workspace shared folder
 	 *
 	 * @param userIdToNotify the user you want to notify
-	 * @param sharedFolder the shared {@link WorkspaceFolder}  
+	 * @param sharedFolder the shared {@link WorkspaceSharedFolder}  
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception;
 	/**
 	 * use to notify a user he got a workspace item new in some of his workspace shared folder
 	 * @param userIdToNotify the user you want to notify
 	 * @param newItem the new shared {@link WorkspaceItem}  
-	 * @param sharedFolder the shared folder {@link WorkspaceFolder}  
+	 * @param sharedFolder the shared folder {@link WorkspaceSharedFolder}  
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyAddedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyAddedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws Exception;
 	/**
 	 * use to notify a user he got a workspace item deleted from one of his workspace shared folder
 	 * @param userIdToNotify the user you want to notify
 	 * @param removedItem the removed {@link WorkspaceItem}  
-	 * @param sharedFolder the shared folder {@link WorkspaceFolder} 
+	 * @param sharedFolder the shared folder {@link WorkspaceSharedFolder} 
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyMovedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyMovedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws Exception;
 	/**
 	 * use to notify a user he got a workspace item deleted from one of his workspace shared folder
 	 * @param userIdToNotify the user you want to notify
 	 * @param removedItem the removed {@link WorkspaceItem}  
-	 * @param sharedFolder the shared folder {@link WorkspaceFolder} 
+	 * @param sharedFolder the shared folder {@link WorkspaceSharedFolder} 
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyRemovedItem(String userIdToNotify, String item, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyRemovedItem(String userIdToNotify, String item, WorkspaceSharedFolder sharedFolder) throws Exception;
 	
 	/**
 	 * use to notify a user he got a workspace item updated from one of his workspace shared folder
@@ -89,16 +115,17 @@ public interface NotificationsManager {
 	 * @param sharedFolder the shared folder {@link WorkspaceFolder} 
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyUpdatedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyUpdatedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws Exception;
 	/**
 	 * use to notify a user he got a workspace item renamed
 	 *
 	 * @param userIdToNotify the user you want to notify
 	 * @param previousName the previous name of the folder
-	 * @param renamedItem the renamed {@link WorkspaceItem}  
+	 * @param renamedItem the renamed {@link WorkspaceItem}
+	 * @param rootSharedFolder the root shared {@link WorkspaceSharedFolder} of the {@link WorkspaceItem}  
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyItemRenaming(String userIdToNotify, String previousName, WorkspaceItem renamedItem) throws Exception;
+	boolean notifyItemRenaming(String userIdToNotify, String previousName, WorkspaceItem renamedItem,  WorkspaceSharedFolder rootSharedFolder) throws Exception;
 	/**
 	 * 
 	 * @param userIdToNotify the user you want to notify
@@ -144,7 +171,7 @@ public interface NotificationsManager {
 	 * @param feedText the liked feed text or a portion of it
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyPost(String userIdToNotify, String feedid, String feedText);
+	boolean notifyPost(String userIdToNotify, String feedid, String feedText, String ... hashtags);
 	/**
 	 * use to notify a user that someone commented on his post
 	 * 
@@ -163,7 +190,7 @@ public interface NotificationsManager {
 	 * @param feedOwnerFullName the full name of the user who created this post
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyCommentReply(String userIdToNotify, String feedid, String feedText, String feedOwnerFullName);
+	boolean notifyCommentReply(String userIdToNotify, String feedid, String feedText, String feedOwnerFullName, String feedOwnerId);
 	/**
 	 * use to notify a user that someone commented on one of his favorite posts 
 	 * 
